@@ -12,15 +12,30 @@ from copy import deepcopy
 import re
 import os
 import html
+from io import BytesIO
+from PIL import Image
+import base64
+
 
 from q2report.q2printer.q2printer import Q2Printer, get_printer
 from q2report.q2utils import num, Q2Heap
 
 re_calc = re.compile(r"\{.*?\}")
+re_q2image = re.compile(r"\{q2image\s*\(\s*.*?\s*\)\}")
 
 engine_name = None
 
 
+def q2image(image, width=0, height=0):
+    if os.path.isfile(image):
+        image = base64.b64encode(open(image, "rb").read()).decode()
+    im = Image.open(BytesIO(base64.b64decode(image)))
+    return f"{image}:{width}:{height}:{im.width}:{im.height}:{im.format}"
+
+
+q2image(r"C:\Users\andre\Desktop\bike.jpg", 9)
+
+
 def set_engine(engine2="PyQt6"):
     global engine
     engine = engine2
@@ -117,13 +132,35 @@ class Q2Report:
         rows_section = deepcopy(rows_section)
         for cell in rows_section["cells"]:
             cell_data = rows_section["cells"][cell].get("data")
-            if cell_data and re_calc.findall(cell_data):
+            if cell_data:
+                #  images
+                cell_data, rows_section["cells"][cell]["images"] = self.extract_images(cell_data)
+                #  text data
                 rows_section["cells"][cell]["data"] = re_calc.sub(self.formulator, cell_data)
 
         row_style = dict(row_style)
         row_style.update(rows_section.get("style", {}))
         self.printer.render_rows_section(rows_section, row_style, self.outline_level)
 
+    def extract_images(self, cell_data):
+        images_list = []
+
+        def extract_image(formula):
+            image_data = self.formulator(formula).split(":")
+            images_list.append(
+                {
+                    "image": image_data[0],
+                    "width": num(image_data[1]),
+                    "height": num(image_data[2]),
+                    "pixel_width": num(image_data[3]),
+                    "pixel_height": num(image_data[4]),
+                }
+            )
+            return ""
+
+        cell_data = re_q2image.sub(extract_image, cell_data)
+        return cell_data, images_list
+
     def run(self, output_file="temp/repo.html", output_type=None, data={}, open_output_file=True):
         self.printer: Q2Printer = get_printer(output_file, output_type)
         report_style = dict(self.report_content["style"])
